from typing import TYPE_CHECKING
import uuid
from sqlmodel import SQLModel, Field, Relationship

if TYPE_CHECKING:
    from ._team import Team
    from ._player import Player


class Trainer(SQLModel, table=True):
    trainer_id: uuid.UUID = Field(
        default_factory=uuid.uuid4,
        primary_key=True,
        unique=True,
        index=True,
        sa_column_kwargs={"comment": "Unique identifier for the trainer"},
    )
    name: str
    age: int
    salary: float

    team_id: uuid.UUID | None = Field(default=None, foreign_key="team.team_id")
    team: "Team" = Relationship(back_populates="trainer")

    players: list["Player"] = Relationship(back_populates="trainer")



from typing import TYPE_CHECKING
import uuid
from sqlmodel import SQLModel, Field, Relationship


if TYPE_CHECKING:
    from ._team import Team
    from ._trainer import Trainer


class Player(SQLModel, table=True):
    player_id: uuid.UUID = Field(
        default_factory=uuid.uuid4,
        primary_key=True,
        unique=True,
        index=True,
        sa_column_kwargs={"comment": "Unique identifier for the player"},
    )
    name: str
    age: int
    weight: int
    height: float
    salary: float
    posicion: str
    pac: float
    sho: float
    pas: float
    dri: float
    defe: float
    phy: float
    goalkeeping: float  

    team_id: uuid.UUID | None = Field(default=None, foreign_key="team.team_id")
    team: "Team" = Relationship(back_populates="players")

    trainer_id: uuid.UUID | None = Field(default=None, foreign_key="trainer.trainer_id")
    trainer: "Trainer" = Relationship(back_populates="players")



from typing import TYPE_CHECKING
import uuid
from sqlmodel import SQLModel, Field, Relationship

if TYPE_CHECKING:
    from ._player import Player
    from ._trainer import Trainer


class Team(SQLModel, table=True):
    team_id: uuid.UUID = Field(
        default_factory=uuid.uuid4,
        primary_key=True,
        unique=True,
        index=True,
        sa_column_kwargs={"comment": "Unique identifier for the team"},
    )
    name: str
    presupuesto: float

    players: list["Player"] = Relationship(back_populates="team")
    trainer: "Trainer" = Relationship(back_populates="team")



from decouple import config
from sqlalchemy.engine import Engine
from sqlmodel import create_engine, SQLModel, Session

from schemas import *


def main():
    postgres_uri: str = config("POSTGRES_URI")
    engine: Engine = create_engine(postgres_uri)
    SQLModel.metadata.create_all(engine)

    with Session(engine) as session:
        team = Team(
            name="Real Madrid", 
            presupuesto=99999999999
        )
        kepa = Player(name="Kepa Arrizabalaga",
                        age=28, 
                        weight=88,
                        height=1.88,
                        salary=9000000,
                        posicion="Goalkeeper", 
                        team=team,
                        pac = 33.5,
                        sho = 24.33,
                        pas = 41.67,
                        dri = 43.83,
                        defe = 18.4,
                        phy = 41,
                        goalkeeping = 85,
        )

        session.add_all([team, 
                         kepa
        ])
        session.commit()


if __name__ == "__main__":
    main()
